@@ -39,7 +39,7 @@ public:
 	explicit knumber_integer(quint64 value);
 	explicit knumber_integer(mpz_t mpz);
 	virtual ~knumber_integer();
-	
+
 public:
 	virtual knumber_base *clone();
 
@@ -47,7 +47,7 @@ public:
 	virtual QString toString(int precision) const;
 	virtual quint64 toUint64() const;
 	virtual qint64 toInt64() const;
-	
+
 public:
 	virtual bool is_even() const;
 	virtual bool is_odd() const;
@@ -61,13 +61,13 @@ public:
 	virtual knumber_base *mul(knumber_base *rhs);
 	virtual knumber_base *div(knumber_base *rhs);
 	virtual knumber_base *mod(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *bitwise_and(knumber_base *rhs);
 	virtual knumber_base *bitwise_xor(knumber_base *rhs);
 	virtual knumber_base *bitwise_or(knumber_base *rhs);
 	virtual knumber_base *bitwise_shift(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *pow(knumber_base *rhs);
 	virtual knumber_base *neg();
@@ -77,16 +77,18 @@ public:
 	virtual knumber_base *cbrt();
 	virtual knumber_base *factorial();
 	virtual knumber_base *reciprocal();
-	
+
 public:
 	virtual knumber_base *log2();
 	virtual knumber_base *log10();
 	virtual knumber_base *ln();
 	virtual knumber_base *exp2();
+	virtual knumber_base *floor();
+	virtual knumber_base *ceil();
 	virtual knumber_base *exp10();
 	virtual knumber_base *exp();
 	virtual knumber_base *bin(knumber_base *rhs);
-	
+
 public:
 	virtual knumber_base *sin();
 	virtual knumber_base *cos();
@@ -100,7 +102,8 @@ public:
 	virtual knumber_base *asinh();
 	virtual knumber_base *acosh();
 	virtual knumber_base *atanh();
-	
+	virtual knumber_base *tgamma();
+
 public:
 	virtual int compare(knumber_base *rhs);
 
